import {createRouter, createWebHistory, RouteRecordRaw} from 'vue-router'
import HomeView from '../views/index/HomeView.vue'

const routes: Array<RouteRecordRaw> = [
    {
        path: '/',
        name: 'login',
        component: () => import('../views/login/LoginView.vue')
    },
    {
        path: '/dashboard',
        name: 'home',
        component: HomeView
    },
    {
        path: '/about',
        name: 'about',
        component: () => import('../views/AboutView.vue')
    },
    {
        path: '/register',
        name: 'register',
        component: () => import('../views/login/RegisterView.vue')
    },
    // 管理后台路由
    {
        path: '/user-management',
        name: 'userManagement',
        component: () => import('../views/UserManagement.vue')
    },
    {
        path: '/order-management',
        name: 'orderManagement',
        component: () => import('../views/OrderManagement.vue')
    },
    {
        path: '/goods-management',
        name: 'goodsManagement',
        component: () => import('../views/GoodsManagement.vue')
    },
    /* 暂时注释掉有问题的组件
    {
        path: '/category-management',
        name: 'categoryManagement',
        component: () => import('../views/CategoryManagement.vue')
    },
    */
    // 添加其他已有页面的路由
    {
        path: '/appraises-management',
        name: 'appraisesManagement',
        component: () => import('../views/AppraisesManagement.vue')
    },
    /* 暂时注释掉有问题的组件
    {
        path: '/user-address-management',
        name: 'userAddressManagement',
        component: () => import('../views/UserAddressManagement.vue')
    },
    */
    {
        path: '/chat-message-management',
        name: 'chatMessageManagement',
        component: () => import('../views/ChatMessageManagement.vue')
    },
    {
        path: '/favorite-good-management',
        name: 'favoriteGoodManagement',
        component: () => import('../views/FavoriteGoodManagement.vue')
    },
    {
        path: '/picture-management',
        name: 'pictureManagement',
        component: () => import('../views/PictureManagement.vue')
    }
]

const router = createRouter({
    history: createWebHistory(process.env.BASE_URL),
    routes
})

// 全局路由守卫，添加鉴权功能
router.beforeEach((to, from, next) => {
    // 免登录白名单
    const whiteList = ['/', '/login', '/register'];
    
    // 获取token
    const token = localStorage.getItem('admin_token');
    console.log('路由守卫检查token:', !!token, '当前路由:', to.path);
    
    if (token) {
        // 已登录状态访问登录页，直接跳转到首页
        if (to.path === '/' || to.path === '/login') {
            console.log('已登录状态访问登录页，重定向到dashboard');
            next('/dashboard');
        } else {
            console.log('已登录状态访问受保护页面，正常通过');
            next();
        }
    } else {
        // 未登录
        if (whiteList.includes(to.path)) {
            // 访问白名单，直接通过
            console.log('未登录状态访问白名单页面，正常通过');
            next();
        } else {
            // 未登录且访问非白名单页面，重定向到登录页
            console.log('未登录状态访问受保护页面，重定向到登录页');
            next('/');
        }
    }
});

export default router
